@@ -8,6 +8,7 @@ from mmcv.runner import load_checkpoint
 
 from mmpose.datasets.pipelines import Compose
 from mmpose.models import build_posenet
+from mmpose.utils.hooks import OutputHook
 
 os.environ['KMP_DUPLICATE_LIB_OK'] = 'TRUE'
 
@@ -132,7 +133,11 @@ class LoadImage:
         return results
 
 
-def _inference_single_pose_model(model, img_or_path, bbox, dataset):
+def _inference_single_pose_model(model,
+                                 img_or_path,
+                                 bbox,
+                                 dataset,
+                                 return_heatmap=False):
     """Inference a single bbox.
 
     num_keypoints: K
@@ -143,10 +148,14 @@ def _inference_single_pose_model(model, img_or_path, bbox, dataset):
         bbox (list | np.ndarray): Bounding boxes (with scores),
             shaped (4, ) or (5, ). (left, top, width, height, [score])
         dataset (str): Dataset name.
+        outputs (list[str] | tuple[str]): Names of layers whose output is
+            to be returned, default: None
 
     Returns:
         ndarray[Kx3]: Predicted pose x, y, score.
+        heatmap[N, K, H, W]: Model output heatmap.
     """
+
     cfg = model.cfg
     device = next(model.parameters()).device
 
@@ -180,6 +189,8 @@ def _inference_single_pose_model(model, img_or_path, bbox, dataset):
         flip_pairs = body + foot + face + hand
     elif dataset == 'TopDownAicDataset':
         flip_pairs = [[0, 3], [1, 4], [2, 5], [6, 9], [7, 10], [8, 11]]
+    elif dataset == 'TopDownMpiiDataset':
+        flip_pairs = [[0, 5], [1, 4], [2, 3], [10, 15], [11, 14], [12, 13]]
     elif (dataset == 'TopDownOneHand10KDataset'
           or dataset == 'TopDownFreiHandDataset'
           or dataset == 'TopDownPanopticDataset'):
@@ -222,10 +233,12 @@ def _inference_single_pose_model(model, img_or_path, bbox, dataset):
 
     # forward the model
     with torch.no_grad():
-        all_preds, _, _ = model(
-            return_loss=False, img=data['img'], img_metas=data['img_metas'])
-
-    return all_preds[0]
+        all_preds, _, _, heatmap = model(
+            return_loss=False,
+            return_heatmap=return_heatmap,
+            img=data['img'],
+            img_metas=data['img_metas'])
+    return all_preds[0], heatmap
 
 
 def inference_top_down_pose_model(model,
@@ -233,7 +246,9 @@ def inference_top_down_pose_model(model,
                                   person_bboxes,
                                   bbox_thr=None,
                                   format='xywh',
-                                  dataset='TopDownCocoDataset'):
+                                  dataset='TopDownCocoDataset',
+                                  return_heatmap=False,
+                                  outputs=None):
     """Inference a single image with a list of person bounding boxes.
 
     num_people: P
@@ -252,35 +267,53 @@ def inference_top_down_pose_model(model,
             'xyxy' means (left, top, right, bottom),
             'xywh' means (left, top, width, height).
         dataset (str): Dataset name, e.g. 'TopDownCocoDataset'.
+        return_heatmap (bool) : Flag to return heatmap, default: False
+        outputs (list(str) | tuple(str)) : Names of layers whose outputs
+            need to be returned, default: None
 
     Returns:
-        list[dict]: The bbox & pose info.
-
+        list[dict]: The bbox & pose info,
             Each item in the list is a dictionary,
             containing the bbox: (left, top, right, bottom, [score])
             and the pose (ndarray[Kx3]): x, y, score
+        list[dict[np.ndarray[N, K, H, W] | torch.tensor[N, K, H, W]]]:
+            Output feature maps from layers specified in `outputs`.
+            Includes 'heatmap' if `return_heatmap` is True.
     """
     # only two kinds of bbox format is supported.
     assert format in ['xyxy', 'xywh']
     # transform the bboxes format to xywh
     if format == 'xyxy':
         person_bboxes = _xyxy2xywh(np.array(person_bboxes))
+
     pose_results = []
+    returned_outputs = []
 
     if len(person_bboxes) > 0:
         if bbox_thr is not None:
             person_bboxes = person_bboxes[person_bboxes[:, 4] > bbox_thr]
-        for bbox in person_bboxes:
-            pose = _inference_single_pose_model(model, img_or_path, bbox,
-                                                dataset)
-            pose_results.append({
-                'bbox':
-                _xywh2xyxy(np.expand_dims(np.array(bbox), 0)),
-                'keypoints':
-                pose,
-            })
 
-    return pose_results
+        with OutputHook(model, outputs=outputs, as_tensor=True) as h:
+            for bbox in person_bboxes:
+                pose, heatmap = _inference_single_pose_model(
+                    model,
+                    img_or_path,
+                    bbox,
+                    dataset,
+                    return_heatmap=return_heatmap)
+
+                if return_heatmap:
+                    h.layer_outputs['heatmap'] = heatmap
+
+                returned_outputs.append(h.layer_outputs)
+                pose_results.append({
+                    'bbox':
+                    _xywh2xyxy(np.expand_dims(np.array(bbox), 0)),
+                    'keypoints':
+                    pose
+                })
+
+    return pose_results, returned_outputs
 
 
 def inference_bottom_up_pose_model(model, img_or_path):
@@ -336,7 +369,7 @@ def inference_bottom_up_pose_model(model, img_or_path):
 
     # forward the model
     with torch.no_grad():
-        all_preds, _, _ = model(
+        all_preds, _, _, heatmap = model(
             return_loss=False, img=data['img'], img_metas=data['img_metas'])
 
     for pred in all_preds:
@@ -344,7 +377,7 @@ def inference_bottom_up_pose_model(model, img_or_path):
             'keypoints': pred[:, :3],
         })
 
-    return pose_results
+    return pose_results, heatmap
 
 
 def vis_pose_result(model,
@@ -436,6 +469,18 @@ def vis_pose_result(model,
             9, 9, 9, 9, 9, 9, 16, 16, 16, 16, 16, 16, 0, 0
         ]]
 
+    elif dataset == 'TopDownMpiiDataset':
+        skeleton = [[1, 2], [2, 3], [3, 7], [7, 4], [4, 5], [5, 6], [7, 8],
+                    [8, 9], [9, 10], [9, 13], [13, 12], [12, 11], [9, 14],
+                    [14, 15], [15, 16]]
+
+        pose_limb_color = palette[[
+            16, 16, 16, 16, 16, 16, 7, 7, 0, 9, 9, 9, 9, 9, 9
+        ]]
+        pose_kpt_color = palette[[
+            16, 16, 16, 16, 16, 16, 7, 7, 0, 0, 9, 9, 9, 9, 9, 9
+        ]]
+
     elif (dataset == 'TopDownOneHand10KDataset'
           or dataset == 'TopDownFreiHandDataset'
           or dataset == 'TopDownPanopticDataset'):
