@@ -13,46 +13,30 @@ from .bottom_up_base_dataset import BottomUpBaseDataset
 
 @DATASETS.register_module()
 class BottomUpCocoDataset(BottomUpBaseDataset):
-    """CocoDataset dataset for bottom-up pose estimation.
+    """COCO dataset for bottom-up pose estimation.
 
     The dataset loads raw features and apply specified transforms
     to return a dict containing the image tensors and other information.
 
-    Keypoint Order:
-
-    .. code-block:: JSON
-
-      {
-        "keypoints":
-        {
-          "0": "nose",
-          "1": "left_eye",
-          "2": "right_eye",
-          "3": "left_ear",
-          "4": "right_ear",
-          "5": "left_shoulder",
-          "6": "right_shoulder",
-          "7": "left_elbow",
-          "8": "right_elbow",
-          "9": "left_wrist",
-          "10": "right_wrist",
-          "11": "left_hip",
-          "12": "right_hip",
-          "13": "left_knee",
-          "14": "right_knee",
-          "15": "left_ankle",
-          "16": "right_ankle"
-        },
-        "skeleton":
-        [
-          [16,14],[14,12],[17,15],[15,13],[12,13],[6,12],
-          [7,13],[6,7],[6,8],[7,9],[8,10],[9,11],[2,3],
-          [1,2],[1,3],[2,4],[3,5],[4,6],[5,7]
-        ]
-      }
-
-
+    COCO keypoint indexes::
 
+        0: 'nose',
+        1: 'left_eye',
+        2: 'right_eye',
+        3: 'left_ear',
+        4: 'right_ear',
+        5: 'left_shoulder',
+        6: 'right_shoulder',
+        7: 'left_elbow',
+        8: 'right_elbow',
+        9: 'left_wrist',
+        10: 'right_wrist',
+        11: 'left_hip',
+        12: 'right_hip',
+        13: 'left_knee',
+        14: 'right_knee',
+        15: 'left_ankle',
+        16: 'right_ankle'
 
     Args:
         ann_file (str): Path to the annotation file.
@@ -70,7 +54,6 @@ class BottomUpCocoDataset(BottomUpBaseDataset):
                  data_cfg,
                  pipeline,
                  test_mode=False):
-
         super().__init__(ann_file, img_prefix, data_cfg, pipeline, test_mode)
 
         self.ann_info['flip_index'] = [
@@ -85,18 +68,16 @@ class BottomUpCocoDataset(BottomUpBaseDataset):
             ],
             dtype=np.float32).reshape((self.ann_info['num_joints'], 1))
 
+        self.sigmas = np.array([
+            .26, .25, .25, .35, .35, .79, .79, .72, .72, .62, .62, 1.07, 1.07,
+            .87, .87, .89, .89
+        ]) / 10.0
+
         self.coco = COCO(ann_file)
 
         cats = [
             cat['name'] for cat in self.coco.loadCats(self.coco.getCatIds())
         ]
-        self.ids = list(self.coco.imgs.keys())
-        if not test_mode:
-            self.ids = [
-                img_id for img_id in self.ids
-                if len(self.coco.getAnnIds(imgIds=img_id, iscrowd=None)) > 0
-            ]
-
         self.classes = ['__background__'] + cats
         self.num_classes = len(self.classes)
         self._class_to_ind = dict(zip(self.classes, range(self.num_classes)))
@@ -104,12 +85,37 @@ class BottomUpCocoDataset(BottomUpBaseDataset):
         self._coco_ind_to_class_ind = dict(
             (self._class_to_coco_ind[cls], self._class_to_ind[cls])
             for cls in self.classes[1:])
+        self.img_ids = self.coco.getImgIds()
+        if not test_mode:
+            self.img_ids = [
+                img_id for img_id in self.img_ids
+                if len(self.coco.getAnnIds(imgIds=img_id, iscrowd=None)) > 0
+            ]
+        self.num_images = len(self.img_ids)
+        self.id2name, self.name2id = self._get_mapping_id_name(self.coco.imgs)
+        self.dataset_name = 'coco'
 
-        self.num_images = len(self.ids)
+        print(f'=> num_images: {self.num_images}')
 
-    def __len__(self):
-        """Get dataset length."""
-        return len(self.ids)
+    def _get_mapping_id_name(self, imgs):
+        """
+        Args:
+            imgs (dict): dict of image info.
+
+        Returns:
+            tuple: Image name & id mapping dicts.
+
+            - id2name (dict): Mapping image id to name.
+            - name2id (dict): Mapping image name to id.
+        """
+        id2name = {}
+        name2id = {}
+        for image_id, image in imgs.items():
+            file_name = image['file_name']
+            id2name[image_id] = file_name
+            name2id[file_name] = image_id
+
+        return id2name, name2id
 
     def _get_single(self, idx):
         """Get anno for a single image.
@@ -121,7 +127,7 @@ class BottomUpCocoDataset(BottomUpBaseDataset):
             dict: info for model training
         """
         coco = self.coco
-        img_id = self.ids[idx]
+        img_id = self.img_ids[idx]
         ann_ids = coco.getAnnIds(imgIds=img_id)
         anno = coco.loadAnns(ann_ids)
 
@@ -138,10 +144,9 @@ class BottomUpCocoDataset(BottomUpBaseDataset):
         ]
 
         db_rec = {}
-        db_rec['dataset'] = 'coco'
-        db_rec['image_file'] = os.path.join(
-            self.img_prefix,
-            coco.loadImgs(img_id)[0]['file_name'])
+        db_rec['dataset'] = self.dataset_name
+        db_rec['image_file'] = os.path.join(self.img_prefix,
+                                            self.id2name[img_id])
         db_rec['mask'] = mask_list
         db_rec['joints'] = joints_list
 
@@ -176,22 +181,23 @@ class BottomUpCocoDataset(BottomUpBaseDataset):
     def _get_mask(self, anno, idx):
         """Get ignore masks to mask out losses."""
         coco = self.coco
-        img_info = coco.loadImgs(self.ids[idx])[0]
+        img_info = coco.loadImgs(self.img_ids[idx])[0]
 
         m = np.zeros((img_info['height'], img_info['width']), dtype=np.float32)
 
         for obj in anno:
-            if obj['iscrowd']:
-                rle = xtcocotools.mask.frPyObjects(obj['segmentation'],
-                                                   img_info['height'],
-                                                   img_info['width'])
-                m += xtcocotools.mask.decode(rle)
-            elif obj['num_keypoints'] == 0:
-                rles = xtcocotools.mask.frPyObjects(obj['segmentation'],
-                                                    img_info['height'],
-                                                    img_info['width'])
-                for rle in rles:
+            if 'segmentation' in obj:
+                if obj['iscrowd']:
+                    rle = xtcocotools.mask.frPyObjects(obj['segmentation'],
+                                                       img_info['height'],
+                                                       img_info['width'])
                     m += xtcocotools.mask.decode(rle)
+                elif obj['num_keypoints'] == 0:
+                    rles = xtcocotools.mask.frPyObjects(
+                        obj['segmentation'], img_info['height'],
+                        img_info['width'])
+                    for rle in rles:
+                        m += xtcocotools.mask.decode(rle)
 
         return m < 0.5
 
@@ -204,7 +210,7 @@ class BottomUpCocoDataset(BottomUpBaseDataset):
             num_keypoints: K
 
         Args:
-            outputs (list(preds, scores, image_path)):Output results.
+            outputs (list(preds, scores, image_path, output_heatmap)):
 
                 * preds (list[images x np.ndarray(P, K, 3+tag_num)]):
                   Pose predictions for all people in images.
@@ -213,6 +219,7 @@ class BottomUpCocoDataset(BottomUpBaseDataset):
                   '/',i','m','a','g','e','s','/', 'v','a', 'l',
                   '2', '0', '1', '7', '/', '0', '0', '0', '0', '0',
                   '0', '3', '9', '7', '1', '3', '3', '.', 'j', 'p', 'g']
+                * output_heatmap (np.ndarray[N, K, H, W]): model outputs.
 
             res_folder (str): Path of directory to save the results.
             metric (str | list[str]): Metric to be performed. Defaults: 'mAP'.
@@ -232,7 +239,7 @@ class BottomUpCocoDataset(BottomUpBaseDataset):
         scores = []
         image_paths = []
 
-        for _preds, _scores, _image_path in outputs:
+        for _preds, _scores, _image_path, _ in outputs:
             preds.append(_preds)
             scores.append(_scores)
             image_paths.append(''.join(_image_path))
@@ -240,24 +247,20 @@ class BottomUpCocoDataset(BottomUpBaseDataset):
         kpts = defaultdict(list)
         # iterate over images
         for idx, _preds in enumerate(preds):
-            file_name = image_paths[idx]
+            str_image_path = image_paths[idx]
+            image_id = self.name2id[os.path.basename(str_image_path)]
             # iterate over people
             for idx_person, kpt in enumerate(_preds):
                 # use bbox area
                 area = (np.max(kpt[:, 0]) - np.min(kpt[:, 0])) * (
                     np.max(kpt[:, 1]) - np.min(kpt[:, 1]))
 
-                kpts[int(file_name[-16:-4])].append({
-                    'keypoints':
-                    kpt[:, 0:3],
-                    'score':
-                    scores[idx][idx_person],
-                    'tags':
-                    kpt[:, 3],
-                    'image_id':
-                    int(file_name[-16:-4]),
-                    'area':
-                    area
+                kpts[image_id].append({
+                    'keypoints': kpt[:, 0:3],
+                    'score': scores[idx][idx_person],
+                    'tags': kpt[:, 3],
+                    'image_id': image_id,
+                    'area': area,
                 })
 
         oks_nmsed_kpts = []
@@ -332,7 +335,7 @@ class BottomUpCocoDataset(BottomUpBaseDataset):
     def _do_python_keypoint_eval(self, res_file):
         """Keypoint evaluation using COCOAPI."""
         coco_det = self.coco.loadRes(res_file)
-        coco_eval = COCOeval(self.coco, coco_det, 'keypoints')
+        coco_eval = COCOeval(self.coco, coco_det, 'keypoints', self.sigmas)
         coco_eval.params.useSegm = None
         coco_eval.evaluate()
         coco_eval.accumulate()
