@@ -102,8 +102,8 @@ class TopDownCocoDataset(TopDownBaseDataset):
         self._coco_ind_to_class_ind = dict(
             (self._class_to_coco_ind[cls], self._class_to_ind[cls])
             for cls in self.classes[1:])
-        self.image_set_index = self.coco.getImgIds()
-        self.num_images = len(self.image_set_index)
+        self.img_ids = self.coco.getImgIds()
+        self.num_images = len(self.img_ids)
         self.id2name, self.name2id = self._get_mapping_id_name(self.coco.imgs)
         self.dataset_name = 'coco'
 
@@ -145,31 +145,33 @@ class TopDownCocoDataset(TopDownBaseDataset):
     def _load_coco_keypoint_annotations(self):
         """Ground truth bbox and keypoints."""
         gt_db = []
-        for index in self.image_set_index:
-            gt_db.extend(self._load_coco_keypoint_annotation_kernel(index))
+        for img_id in self.img_ids:
+            gt_db.extend(self._load_coco_keypoint_annotation_kernel(img_id))
         return gt_db
 
-    def _load_coco_keypoint_annotation_kernel(self, index):
+    def _load_coco_keypoint_annotation_kernel(self, img_id):
         """load annotation from COCOAPI.
 
         Note:
             bbox:[x1, y1, w, h]
         Args:
-            index: coco image id
+            img_id: coco image id
         Returns:
             dict: db entry
         """
-        img_ann = self.coco.loadImgs(index)[0]
+        img_ann = self.coco.loadImgs(img_id)[0]
         width = img_ann['width']
         height = img_ann['height']
         num_joints = self.ann_info['num_joints']
 
-        ann_ids = self.coco.getAnnIds(imgIds=index, iscrowd=False)
+        ann_ids = self.coco.getAnnIds(imgIds=img_id, iscrowd=False)
         objs = self.coco.loadAnns(ann_ids)
 
         # sanitize bboxes
         valid_objs = []
         for obj in objs:
+            if 'bbox' not in obj:
+                continue
             x, y, w, h = obj['bbox']
             x1 = max(0, x)
             y1 = max(0, y)
@@ -182,8 +184,12 @@ class TopDownCocoDataset(TopDownBaseDataset):
 
         rec = []
         for obj in objs:
+            if 'keypoints' not in obj:
+                continue
             if max(obj['keypoints']) == 0:
                 continue
+            if 'num_keypoints' in obj and obj['num_keypoints'] == 0:
+                continue
             joints_3d = np.zeros((num_joints, 3), dtype=np.float32)
             joints_3d_visible = np.zeros((num_joints, 3), dtype=np.float32)
 
@@ -193,7 +199,7 @@ class TopDownCocoDataset(TopDownBaseDataset):
 
             center, scale = self._xywh2cs(*obj['clean_bbox'][:4])
 
-            image_file = os.path.join(self.img_prefix, self.id2name[index])
+            image_file = os.path.join(self.img_prefix, self.id2name[img_id])
             rec.append({
                 'image_file': image_file,
                 'center': center,
@@ -275,7 +281,7 @@ class TopDownCocoDataset(TopDownBaseDataset):
                 'scale': scale,
                 'rotation': 0,
                 'bbox_score': score,
-                'dataset': 'coco',
+                'dataset': self.dataset_name,
                 'joints_3d': joints_3d,
                 'joints_3d_visible': joints_3d_visible
             })
@@ -288,10 +294,13 @@ class TopDownCocoDataset(TopDownBaseDataset):
         saved in `${res_folder}/result_keypoints.json`.
 
         Note:
+            batch_size: N
             num_keypoints: K
+            heatmap height: H
+            heatmap width: W
 
         Args:
-            outputs (list(preds, boxes, image_path))
+            outputs (list(preds, boxes, image_path, heatmap))
                 :preds (np.ndarray[1,K,3]): The first two dimensions are
                     coordinates, score is the third dimension of the array.
                 :boxes (np.ndarray[1,6]): [center[0], center[1], scale[0]
@@ -299,6 +308,7 @@ class TopDownCocoDataset(TopDownBaseDataset):
                 :image_path (list[str]): For example, [ '/', 'v','a', 'l',
                     '2', '0', '1', '7', '/', '0', '0', '0', '0', '0',
                     '0', '3', '9', '7', '1', '3', '3', '.', 'j', 'p', 'g']
+                :heatmap (np.ndarray[N, K, H, W]): model output heatmap.
             res_folder (str): Path of directory to save the results.
             metric (str | list[str]): Metric to be performed. Defaults: 'mAP'.
 
@@ -314,9 +324,9 @@ class TopDownCocoDataset(TopDownBaseDataset):
         res_file = os.path.join(res_folder, 'result_keypoints.json')
 
         kpts = defaultdict(list)
-        for preds, boxes, image_path in outputs:
+        for preds, boxes, image_path, _ in outputs:
             str_image_path = ''.join(image_path)
-            image_id = self.name2id[os.path.basename(str_image_path)]
+            image_id = self.name2id[str_image_path[len(self.img_prefix):]]
 
             kpts[image_id].append({
                 'keypoints': preds[0],
@@ -332,8 +342,8 @@ class TopDownCocoDataset(TopDownBaseDataset):
         vis_thr = self.vis_thr
         oks_thr = self.oks_thr
         oks_nmsed_kpts = []
-        for img in kpts.keys():
-            img_kpts = kpts[img]
+        for image_id in kpts.keys():
+            img_kpts = kpts[image_id]
             for n_p in img_kpts:
                 box_score = n_p['score']
                 kpt_score = 0
